==> elpy_1.28.0.orig.tar.xz: elpy-1.28.0/test/elpy-rpc--find-buffer-test.el <==
(ert-deftest elpy-rpc--find-buffer-should-find-correct-buffer ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) (equal buf buffer)))
      (setq elpy-rpc--backend-library-root "test-project"
            elpy-rpc--backend-python-command (executable-find "python"))
      (should (equal (elpy-rpc--find-buffer "test-project"
                                            "python")
                     (current-buffer))))))

(ert-deftest elpy-rpc--find-buffer-should-not-find-without-process-buffer ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) nil))
      (setq elpy-rpc--backend-library-root "test-project"
            elpy-rpc--backend-python-command (executable-find "python"))

      (should (equal (elpy-rpc--find-buffer "test-project"
                                            "python")
                     nil)))))

(ert-deftest elpy-rpc--find-buffer-should-not-find-with-bad-project-root ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) t))
      (setq elpy-rpc--backend-library-root "bad-test-project"
            elpy-rpc--backend-python-command (executable-find "python"))

      (should (equal (elpy-rpc--find-buffer "test-project"
                                            "python")
                     nil)))))

(ert-deftest elpy-rpc--find-buffer-should-not-find-without-bad-python-command ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) t))
      (setq elpy-rpc--backend-library-root "test-project"
            elpy-rpc--backend-python-command "bad-test-python-command")

      (should (equal (elpy-rpc--find-buffer "test-project"
                                            "test-python-command")
                     nil)))))

==> elpy_1.32.0.orig.tar.xz: elpy-1.32.0/test/elpy-rpc--find-buffer-test.el <==
(ert-deftest elpy-rpc--find-buffer-should-find-correct-buffer ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) (equal buf buffer)))
      (setq elpy-rpc--backend-library-root "test-project"
            elpy-rpc--backend-python-command (executable-find elpy-rpc-python-command))
      (should (equal (elpy-rpc--find-buffer "test-project"
                                            elpy-rpc-python-command)
                     (current-buffer))))))

(ert-deftest elpy-rpc--find-buffer-should-not-find-without-process-buffer ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) nil))
      (setq elpy-rpc--backend-library-root "test-project"
            elpy-rpc--backend-python-command (executable-find elpy-rpc-python-command))

      (should (equal (elpy-rpc--find-buffer "test-project"
                                            elpy-rpc-python-command)
                     nil)))))

(ert-deftest elpy-rpc--find-buffer-should-not-find-with-bad-project-root ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) t))
      (setq elpy-rpc--backend-library-root "bad-test-project"
            elpy-rpc--backend-python-command (executable-find elpy-rpc-python-command))

      (should (equal (elpy-rpc--find-buffer "test-project"
                                            elpy-rpc-python-command)
                     nil)))))

(ert-deftest elpy-rpc--find-buffer-should-not-find-without-bad-python-command ()
  (elpy-testcase ()
    (mletf* ((buffer (current-buffer))
             (elpy-rpc--process-buffer-p (buf) t))
      (setq elpy-rpc--backend-library-root "test-project"
            elpy-rpc--backend-python-command "bad-test-python-command")

      (should (equal (elpy-rpc--find-buffer "test-project"
                                            "test-python-command")
                     nil)))))
